
Hi, NumpyDL
===========

NumpyDL is a simple deep learning library based on pure Python/Numpy. NumpyDL
is a work in progress, input is welcome. The project is on
`GitHub <https://github.com/oujago/NumpyDL>`_.

The main features of NumpyDL are as follows:

1. *Pure* in Numpy
2. *Native* to Python
3. *Automatic differentiations* are basically supported
4. *Commonly used models* are provided: MLP, RNNs, LSTMs and CNNs
5. *API* like ``Keras`` library
6. *Examples* for several AI tasks
7. *Application* for a toy chatbot


User Guides
===========

The NumpyDL user guide explains how to install NumpyDL, how to build and train
neural networks using NumpyDL, and how to contribute to the library as a
developer.

.. toctree::
   :maxdepth: 2
   :numbered:

   user_guides/installation
   user_guides/development


Tutorials
=========

This is the tutorials of Deep Learning.

.. toctree::
   :maxdepth: 2
   :numbered:

   tutorials/activations
   tutorials/initializations
   tutorials/objectives
   tutorials/optimizers
   tutorials/MLP
   tutorials/CNN
   tutorials/RNN


API References
==============

If you are looking for information on a specific function, class or
method, this part of the documentation is for you.

.. toctree::
   :maxdepth: 2

   api_references/layers
   api_references/activations
   api_references/initializations
   api_references/objectives
   api_references/optimizers
   api_references/model
   api_references/utils


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _GitHub: https://github.com/oujago/NumpyDL
